@@ -1,4 +1,4 @@
-# $Id: Event.pm 2017 2006-08-03 16:05:34Z rcaputo $
+# $Id: Event.pm 2084 2006-09-01 03:31:22Z rcaputo $
 
 # Event.pm event loop bridge for POE::Kernel.
 
@@ -8,7 +8,7 @@ package POE::Loop::Event;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = do {my($r)=(q$Revision: 2017 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = do {my($r)=(q$Revision: 2084 $=~/(\d+)/);sprintf"1.%04d",$r};
 
 # Everything plugs into POE::Kernel.
 package POE::Kernel;
@@ -22,17 +22,9 @@ my %signal_watcher;
 #------------------------------------------------------------------------------
 # Loop construction and destruction.
 
-sub _our_event_exception_handler {
-  my ($event, $message) = @_;
-  warn $message;
-  exit 1;
-}
-
 sub loop_initialize {
   my $self = shift;
 
-  $Event::DIED = \&_our_event_exception_handler;
-
   $_watcher_timer = Event->timer(
     cb     => \&_loop_event_callback,
     after  => 0,
@@ -154,17 +146,20 @@ sub loop_attach_uidestroy {
 
 sub loop_resume_time_watcher {
   my ($self, $next_time) = @_;
+  ($_watcher_timer and $next_time) or return;
   $_watcher_timer->at($next_time);
   $_watcher_timer->start();
 }
 
 sub loop_reset_time_watcher {
   my ($self, $next_time) = @_;
+  $_watcher_timer or return;
   $self->loop_pause_time_watcher();
   $self->loop_resume_time_watcher($next_time);
 }
 
 sub loop_pause_time_watcher {
+  $_watcher_timer or return;
   $_watcher_timer->stop();
 }
 
@@ -237,24 +232,6 @@ sub _loop_event_callback {
   $self->_data_ev_dispatch_due();
   $self->_test_if_kernel_is_idle();
 
-  # Register the next timed callback if there are events left.
-
-  my $next_time = $self->get_next_event_time();
-  if (defined $next_time) {
-    $_watcher_timer->at($next_time);
-    $_watcher_timer->start();
-
-    # POE::Kernel's signal polling loop always keeps oe event in the
-    # queue.  We test for an idle kernel if the queue holds only one
-    # event.  A more generic method would be to keep counts of user
-    # vs. kernel events, and GC the kernel when the user events drop
-    # to 0.
-
-    if ($self->_data_ses_count() == 1) {
-      $self->_test_if_kernel_is_idle();
-    }
-  }
-
   # Transferring control back to Event; this is idle time.
   $last_time = time() if TRACE_STATISTICS;
 }
@@ -288,15 +265,19 @@ sub _loop_select_callback {
 # The event loop itself.
 
 sub loop_do_timeslice {
-  die "doing timeslices currently not supported in the Event loop";
+  Event::one_event();
 }
 
 sub loop_run {
-  Event::loop();
+  my $self = shift;
+  while ($self->_data_ses_count()) {
+    $self->loop_do_timeslice();
+  }
 }
 
 sub loop_halt {
   $_watcher_timer->stop();
+  $_watcher_timer = undef;
   Event::unloop_all(0);
 }
 
