@@ -1,12 +1,12 @@
-# $Id: Signals.pm 1954 2006-05-08 06:30:44Z teknikill $
+# $Id: Signals.pm 2087 2006-09-01 10:24:43Z bsmith $
 
 # The data necessary to manage signals, and the accessors to get at
 # that data in a sane fashion.
 
-package POE::Resources::Signals;
+package POE::Resource::Signals;
 
 use vars qw($VERSION);
-$VERSION = do {my($r)=(q$Revision: 1954 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = do {my($r)=(q$Revision: 2087 $=~/(\d+)/);sprintf"1.%04d",$r};
 
 # These methods are folded into POE::Kernel;
 package POE::Kernel;
@@ -95,13 +95,15 @@ sub _data_sig_initialize {
 
       # Nonexistent signals, and ones which are globally unhandled.
       next if (
-        $signal =~ /^( NUM\d+
-                     |__[A-Z0-9]+__
-                     |ALL|CATCHALL|DEFER|HOLD|IGNORE|MAX|PAUSE
-                     |RTMIN|RTMAX|SETS
-                     |SEGV
-                     |
-                     )$/x
+        $signal =~ /^
+          ( NUM\d+
+          |__[A-Z0-9]+__
+          |ALL|CATCHALL|DEFER|HOLD|IGNORE|MAX|PAUSE
+          |RTMIN|RTMAX|SETS
+          |SEGV
+          |
+          )
+        $/x
       );
 
       # Windows doesn't have a SIGBUS, but the debugger causes SIGBUS
@@ -111,13 +113,15 @@ sub _data_sig_initialize {
       # Apache uses SIGCHLD and/or SIGCLD itself, so we can't.
       next if $signal =~ /^CH?LD$/ and exists $INC{'Apache.pm'};
 
-      # Reset the signal handler.  Some signal handlers are set to
-      # IGNORE, while most are kept to DEFAULT.  The event loop will
-      # know what to do.
-      $self->loop_ignore_signal($signal);
-
       $_safe_signals{$signal} = 1;
     }
+
+    # Reset some important signal handlers.  The rest remain
+    # untouched.
+
+    $self->loop_ignore_signal("CHLD") if exists $SIG{CHLD};
+    $self->loop_ignore_signal("CLD")  if exists $SIG{CLD};
+    $self->loop_ignore_signal("PIPE") if exists $SIG{PIPE};
   }
 }
 
@@ -167,12 +171,28 @@ sub _data_sig_finalize {
 sub _data_sig_count_ses {
   my ($self, $session) = @_;
 
-  if (exists( $kr_sessions_to_signals{$session} )) {
-    return scalar keys %{$kr_sessions_to_signals{$session}};
-  }
-  else {
-    return 0;
+  return 0 unless exists $kr_sessions_to_signals{$session};
+  return scalar keys %{$kr_sessions_to_signals{$session}};
+}
+
+# Return a count of signals watched by sessions that aren't the
+# Kernel.  Also, don't count IDLE or ZOMBIE signals, otherwise a
+# program watching for them will never receive them.
+#
+# TODO - This is slow, and it's called relatively often.  We should
+# maintain a reference count as signals are added ard removed rather
+# than recalculate the count each time.
+
+sub _data_sig_count {
+  my $signal_count;
+  foreach my $session (keys %kr_sessions_to_signals) {
+    next if $session eq $poe_kernel;
+    foreach my $signal (keys %{$kr_sessions_to_signals{$session}}) {
+      next if $signal eq "IDLE" or $signal eq "ZOMBIE";
+      $signal_count++;
+    }
   }
+  return $signal_count;
 }
 
 ### Add a signal to a session.
@@ -186,7 +206,7 @@ sub _data_sig_add {
   ) {
     $self->_data_ses_refcount_inc( $session );
   }
-  
+
   $kr_sessions_to_signals{$session}->{$signal} = $event;
   $kr_signals{$signal}->{$session} = $event;
 
@@ -508,7 +528,7 @@ __END__
 
 =head1 NAME
 
-POE::Resources::Signals - signal management for POE::Kernel
+POE::Resource::Signals - signal management for POE::Kernel
 
 =head1 SYNOPSIS
 
