@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: Makefile-5004.pm 1781 2005-04-29 01:07:14Z sungo $
+# $Id: Makefile-5004.pm 1995 2006-06-18 20:33:55Z rcaputo $
 
 use strict;
 
@@ -24,18 +24,6 @@ system($^X, "mylib/gen-tests.perl") and die "couldn't generate tests: $!";
 
 ### Generate Makefile.PL.
 
-#sub MY::postamble {
-#    return <<EOF;
-#reportupload: poe_report.xml
-#\cI$^X mylib/reportupload.pl
-#
-#uploadreport: poe_report.xml
-#\cI$^X mylib/reportupload.pl
-#
-#testreport: poe_report.xml
-#
-#poe_report.xml: Makefile
-#\cI$^X mylib/testreport.pl
 sub MY::postamble {
     return <<EOF;
 coverage: Makefile
@@ -66,8 +54,9 @@ WriteMakefile(
     FILES => CLEAN_FILES,
   },
 
-  PL_FILES    => { },
+  PL_FILES  => { },
   PREREQ_PM => { CORE_REQUIREMENTS },
+  PM_FILTER => 'mylib/preprocessor.perl',
 );
 
 1;
